@@ -13,7 +13,7 @@ use Modern::Perl;    ## no critic (UselessNoCritic,RequireExplicitPackage)
 package XML::Ant::BuildFile::Task::Copy;
 
 BEGIN {
-    $XML::Ant::BuildFile::Task::Copy::VERSION = '0.210';
+    $XML::Ant::BuildFile::Task::Copy::VERSION = '0.211';
 }
 
 # ABSTRACT: copy task node in an Ant build file
@@ -29,19 +29,23 @@ use namespace::autoclean;
 extends 'XML::Ant::BuildFile::ResourceContainer';
 with 'XML::Ant::BuildFile::Task';
 
-has _to_file =>
-    ( ro,
-    ## no critic (ValuesAndExpressions::RequireInterpolationOfMetachars)
-    isa         => Str,
-    traits      => ['XPathValue'],
-    xpath_query => './@tofile',
+for my $attr (qw(dir file)) {
+    has "_to_$attr" => ( ro,
+        isa         => Str,
+        traits      => ['XPathValue'],
+        xpath_query => "./\@to$attr",
     );
 
-has to_file => ( ro, lazy,
-    isa => File,
-    default =>
-        sub { dir( XML::Ant::Properties->apply( $ARG[0]->_to_file ) ) },
-);
+    has "to_$attr" => ( ro, lazy,
+        isa     => "Path::Class::\u$attr",
+        default => sub {
+            my $method  = "_to_$attr";
+            my $applied = XML::Ant::Properties->apply( $ARG[0]->$method );
+            ## no critic (ProhibitStringyEval, RequireCheckingReturnValueOfEval)
+            return eval "Path::Class::$attr('$applied')";
+        },
+    );
+}
 
 1;
 
@@ -57,7 +61,7 @@ XML::Ant::BuildFile::Task::Copy - copy task node in an Ant build file
 
 =head1 VERSION
 
-version 0.210
+version 0.211
 
 =head1 SYNOPSIS
 
@@ -83,6 +87,12 @@ build file.
 
 The file to copy to as a L<Path::Class::File|Path::Class::File> object.
 
+=head2 to_dir
+
+The directory to copy a set of
+L<XML::Ant::BuildFile::Resource|XML::Ant::BuildFile::Resource>s to as a
+L<Path::Class::Dir|Path::Class::Dir> object.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
